package org.springblade.common.upyzt.model;

import org.springblade.common.upyzt.exception.UpyztException;
import org.springblade.common.upyzt.net.APIResource;
import org.springblade.common.upyzt.net.RequestOptions;
import org.springblade.common.upyzt.resp.BalanceAcctFreezeResp;
import lombok.experimental.Accessors;

import java.util.Map;

/**
 * 电子账簿冻结操作
 */
@Accessors(chain = true)
public class BalanceAcctFreeze extends APIResource {

    /**
     * 冻结/解冻电子账簿
     *
     * @param params 请求参数
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BalanceAcctFreezeResp create(Map<String, Object> params) throws UpyztException {
        return create(params, null);
    }

    /**
     * 冻结/解冻电子账簿
     *
     * @param params  请求参数
     * @param options 参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BalanceAcctFreezeResp create(Map<String, Object> params, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.POST, classURL(BalanceAcct.class) + "/freeze", params, BalanceAcctFreezeResp.class, options);
    }


    /**
     * 冻结/解冻结果查询（系统订单号）
     *
     * @param id 系统订单号
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BalanceAcctFreezeResp retrieveById(String id) throws UpyztException {
        return retrieveById(id, null);
    }

    /**
     * 冻结/解冻结果查询（系统订单号）
     *
     * @param id      系统订单号
     * @param options 参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BalanceAcctFreezeResp retrieveById(String id, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.GET, classURL(BalanceAcct.class, "/freeze/" + id), null, BalanceAcctFreezeResp.class, options);
    }

    /**
     * 冻结/解冻结果查询（平台订单号）
     *
     * @param outRequestNo 平台订单号
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BalanceAcctFreezeResp retrieveByOutRequestNo(String outRequestNo) throws UpyztException {
        return retrieveByOutRequestNo(outRequestNo, null);
    }

    /**
     * 冻结/解冻结果查询（平台订单号）
     *
     * @param outRequestNo 平台订单号
     * @param options      参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BalanceAcctFreezeResp retrieveByOutRequestNo(String outRequestNo, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.GET, classURL(BalanceAcct.class, "/freeze_by_out_request_no/" + outRequestNo), null, BalanceAcctFreezeResp.class, options);
    }
}
