package org.springblade.common.upyzt.model;

import org.springblade.common.upyzt.exception.UpyztException;
import org.springblade.common.upyzt.net.APIResource;
import org.springblade.common.upyzt.net.RequestOptions;
import org.springblade.common.upyzt.resp.BatchPaymentResp;
import lombok.experimental.Accessors;

import java.util.Map;

@Accessors(chain = true)
public class BatchPayment extends APIResource {

    /**
     * 批量消费（转账）
     *
     * @param params 请求参数
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BatchPaymentResp create(Map<String, Object> params) throws UpyztException {
        return create(params, null);
    }

    /**
     * 批量消费（转账）
     *
     * @param params  请求参数
     * @param options 参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BatchPaymentResp create(Map<String, Object> params, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.POST, classURL(BatchPayment.class), params, BatchPaymentResp.class, options);
    }

    /**
     * 批量消费（转账）订单查询（系统订单号）
     *
     * @param id 系统订单号
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BatchPaymentResp retrieveById(String id) throws UpyztException {
        return retrieveById(id, null);
    }

    /**
     * 批量消费（转账）订单查询（系统订单号）
     *
     * @param id      系统订单号
     * @param options 参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BatchPaymentResp retrieveById(String id, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.GET, instanceURL(BatchPayment.class, id), null, BatchPaymentResp.class, options);
    }

    /**
     * 批量消费（转账）订单查询（平台订单号）
     *
     * @param outOrderNo 平台订单号
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BatchPaymentResp retrieveByOutOrderNo(String outOrderNo) throws UpyztException {
        return retrieveByOutOrderNo(outOrderNo, null);
    }

    /**
     * 批量消费（转账）订单查询（平台订单号）
     *
     * @param outOrderNo 平台订单号
     * @param options    参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static BatchPaymentResp retrieveByOutOrderNo(String outOrderNo, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.GET, instanceURL(BatchPayment.class, "_by_out_order_no", outOrderNo), null, BatchPaymentResp.class, options);
    }

}
