package org.springblade.common.upyzt.model;

import org.springblade.common.upyzt.exception.UpyztException;
import org.springblade.common.upyzt.net.APIResource;
import org.springblade.common.upyzt.net.RequestOptions;
import org.springblade.common.upyzt.resp.CombinedDepositConfirmResp;
import lombok.experimental.Accessors;

import java.util.Map;

@Accessors(chain = true)
public class CombinedDepositConfirm extends APIResource {

    /**
     * 合并支付担保确认
     *
     * @param params 请求参数
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedDepositConfirmResp create(Map<String, Object> params) throws UpyztException {
        return create(params, null);
    }

    /**
     * 合并支付担保确认
     *
     * @param params  请求参数
     * @param options 参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedDepositConfirmResp create(Map<String, Object> params, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.POST, classURL(CombinedDepositConfirm.class), params, CombinedDepositConfirmResp.class, options);
    }

    /**
     * 合并支付担保确认订单查询（系统订单号）
     *
     * @param id 系统订单号
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedDepositConfirmResp retrieveById(String id) throws UpyztException {
        return retrieveById(id, null);
    }

    /**
     * 合并支付担保确认订单查询（系统订单号）
     *
     * @param id      系统订单号
     * @param options 参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedDepositConfirmResp retrieveById(String id, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.GET, instanceURL(CombinedDepositConfirm.class, id), null, CombinedDepositConfirmResp.class, options);
    }

    /**
     * 合并支付担保确认订单查询（平台订单号）
     *
     * @param outOrderNo 平台订单号
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedDepositConfirmResp retrieveByOutOrderNo(String outOrderNo) throws UpyztException {
        return retrieveByOutOrderNo(outOrderNo, null);
    }

    /**
     * 合并支付担保确认订单查询（平台订单号）
     *
     * @param outOrderNo 平台订单号
     * @param options    参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedDepositConfirmResp retrieveByOutOrderNo(String outOrderNo, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.GET, instanceURL(CombinedDepositConfirm.class, "_by_out_order_no", outOrderNo), null, CombinedDepositConfirmResp.class, options);
    }

}
