package org.springblade.common.upyzt.model;

import org.springblade.common.upyzt.exception.UpyztException;
import org.springblade.common.upyzt.net.APIResource;
import org.springblade.common.upyzt.net.RequestOptions;
import org.springblade.common.upyzt.resp.CombinedGuaranteeConfirmResp;
import lombok.experimental.Accessors;

import java.util.Map;

@Accessors(chain = true)
public class CombinedGuaranteeConfirm extends APIResource {

    /**
     * 合并消费担保确认
     *
     * @param params 请求参数
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedGuaranteeConfirmResp create(Map<String, Object> params) throws UpyztException {
        return create(params, null);
    }

    /**
     * 合并消费担保确认
     *
     * @param params  请求参数
     * @param options 参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedGuaranteeConfirmResp create(Map<String, Object> params, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.POST, classURL(CombinedGuaranteeConfirm.class), params, CombinedGuaranteeConfirmResp.class, options);
    }

    /**
     * 合并消费担保确认订单查询（系统订单号）
     *
     * @param id 系统订单号
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedGuaranteeConfirmResp retrieveById(String id) throws UpyztException {
        return retrieveById(id, null);
    }

    /**
     * 合并消费担保确认订单查询（系统订单号）
     *
     * @param id      系统订单号
     * @param options 参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedGuaranteeConfirmResp retrieveById(String id, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.GET, instanceURL(CombinedGuaranteeConfirm.class, id), null, CombinedGuaranteeConfirmResp.class, options);
    }

    /**
     * 合并消费担保确认订单查询（平台订单号）
     *
     * @param outOrderNo 平台订单号
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedGuaranteeConfirmResp retrieveByOutOrderNo(String outOrderNo) throws UpyztException {
        return retrieveByOutOrderNo(outOrderNo, null);
    }

    /**
     * 合并消费担保确认订单查询（平台订单号）
     *
     * @param outOrderNo 平台订单号
     * @param options    参数选项
     * @return 返回参数
     * @throws UpyztException 异常
     */
    public static CombinedGuaranteeConfirmResp retrieveByOutOrderNo(String outOrderNo, RequestOptions options) throws UpyztException {
        return APIResource.request(RequestMethod.GET, instanceURL(CombinedGuaranteeConfirm.class, "_by_out_order_no", outOrderNo), null, CombinedGuaranteeConfirmResp.class, options);
    }

}
