/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.app.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.app.entity.ApiLog;
import org.springblade.modules.app.vo.ApiLogVO;
import org.springblade.modules.app.service.IApiLogService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 *  控制器
 *
 * @author BladeX
 * @since 2022-09-23
 */
@RestController
@AllArgsConstructor
@RequestMapping("app/apilog")
@Api(value = "", tags = "接口")
public class ApiLogController extends BladeController {

	private final IApiLogService apiLogService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	//@ApiOperationSupport(order = 1)
	//@ApiOperation(value = "详情", notes = "传入apiLog")
	public R<ApiLog> detail(ApiLog apiLog) {
		ApiLog detail = apiLogService.getOne(Condition.getQueryWrapper(apiLog));
		return R.data(detail);
	}

	/**
	 * 分页 
	 */
	@GetMapping("/list")
	//@ApiOperationSupport(order = 2)
	//@ApiOperation(value = "分页", notes = "传入apiLog")
	public R<IPage<ApiLog>> list(ApiLog apiLog, Query query) {
		IPage<ApiLog> pages = apiLogService.page(Condition.getPage(query), Condition.getQueryWrapper(apiLog));
		return R.data(pages);
	}

	/**
	 * 自定义分页 
	 */
	@GetMapping("/page")
	//@ApiOperationSupport(order = 3)
	//@ApiOperation(value = "分页", notes = "传入apiLog")
	public R<IPage<ApiLogVO>> page(ApiLogVO apiLog, Query query) {
		IPage<ApiLogVO> pages = apiLogService.selectApiLogPage(Condition.getPage(query), apiLog);
		return R.data(pages);
	}

	/**
	 * 新增 
	 */
	@PostMapping("/save")
	//@ApiOperationSupport(order = 4)
	//@ApiOperation(value = "新增", notes = "传入apiLog")
	public R save(@Valid @RequestBody ApiLog apiLog) {
		return R.status(apiLogService.save(apiLog));
	}

	/**
	 * 修改 
	 */
	@PostMapping("/update")
	//@ApiOperationSupport(order = 5)
	//@ApiOperation(value = "修改", notes = "传入apiLog")
	public R update(@Valid @RequestBody ApiLog apiLog) {
		return R.status(apiLogService.updateById(apiLog));
	}

	/**
	 * 新增或修改 
	 */
	@PostMapping("/submit")
	//@ApiOperationSupport(order = 6)
	//@ApiOperation(value = "新增或修改", notes = "传入apiLog")
	public R submit(@Valid @RequestBody ApiLog apiLog) {
		return R.status(apiLogService.saveOrUpdate(apiLog));
	}

	
	/**
	 * 删除 
	 */
	@PostMapping("/remove")
	//@ApiOperationSupport(order = 8)
	//@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(apiLogService.removeByIds(Func.toLongList(ids)));
	}

	
}
