/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.app.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.app.entity.PaymentAccount;
import org.springblade.modules.app.vo.PaymentAccountVO;
import org.springblade.modules.app.service.IPaymentAccountService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 支付账号表 控制器
 *
 * @author BladeX
 * @since 2022-10-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("app/paymentaccount")
@Api(value = "支付账号表", tags = "支付账号表接口")
public class PaymentAccountController extends BladeController {

	private final IPaymentAccountService paymentAccountService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	//@ApiOperationSupport(order = 1)
	//@ApiOperation(value = "详情", notes = "传入paymentAccount")
	public R<PaymentAccount> detail(PaymentAccount paymentAccount) {
		PaymentAccount detail = paymentAccountService.getOne(Condition.getQueryWrapper(paymentAccount));
		return R.data(detail);
	}

	/**
	 * 分页 支付账号表
	 */
	@GetMapping("/list")
	//@ApiOperationSupport(order = 2)
	//@ApiOperation(value = "分页", notes = "传入paymentAccount")
	public R<IPage<PaymentAccount>> list(PaymentAccount paymentAccount, Query query) {
		IPage<PaymentAccount> pages = paymentAccountService.page(Condition.getPage(query), Condition.getQueryWrapper(paymentAccount));
		return R.data(pages);
	}

	/**
	 * 自定义分页 支付账号表
	 */
	@GetMapping("/page")
	//@ApiOperationSupport(order = 3)
	//@ApiOperation(value = "分页", notes = "传入paymentAccount")
	public R<IPage<PaymentAccountVO>> page(PaymentAccountVO paymentAccount, Query query) {
		IPage<PaymentAccountVO> pages = paymentAccountService.selectPaymentAccountPage(Condition.getPage(query), paymentAccount);
		return R.data(pages);
	}

	/**
	 * 新增 支付账号表
	 */
	@PostMapping("/save")
	//@ApiOperationSupport(order = 4)
	//@ApiOperation(value = "新增", notes = "传入paymentAccount")
	public R save(@Valid @RequestBody PaymentAccount paymentAccount) {
		return R.status(paymentAccountService.save(paymentAccount));
	}

	/**
	 * 修改 支付账号表
	 */
	@PostMapping("/update")
	//@ApiOperationSupport(order = 5)
	//@ApiOperation(value = "修改", notes = "传入paymentAccount")
	public R update(@Valid @RequestBody PaymentAccount paymentAccount) {
		return R.status(paymentAccountService.updateById(paymentAccount));
	}

	/**
	 * 新增或修改 支付账号表
	 */
	@PostMapping("/submit")
	//@ApiOperationSupport(order = 6)
	//@ApiOperation(value = "新增或修改", notes = "传入paymentAccount")
	public R submit(@Valid @RequestBody PaymentAccount paymentAccount) {
		return R.status(paymentAccountService.saveOrUpdate(paymentAccount));
	}

	
	/**
	 * 删除 支付账号表
	 */
	@PostMapping("/remove")
	//@ApiOperationSupport(order = 8)
	//@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(paymentAccountService.removeByIds(Func.toLongList(ids)));
	}

	
}
