/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.app.entity;

import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * 支付账号表实体类
 *
 * @author BladeX
 * @since 2022-10-14
 */
@Data
@TableName("tb_payment_account")
@ApiModel(value = "PaymentAccount对象", description = "支付账号表")
public class PaymentAccount implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	* 主键id
	*/
		@ApiModelProperty(value = "主键id")
		@TableId(value = "id", type = IdType.AUTO)
	private Integer id;
	/**
	* 用户id
	*/
		@ApiModelProperty(value = "用户id")
		private Long userId;
	/**
	* 账户编号
	*/
		@ApiModelProperty(value = "账户编号")
		private String accountCode;
	/**
	* 	账号类型	11：现金账户管理	12：记账账户管理	13：嘉联支付账户	14： 运直通支付账户	15: 兴业支付账户	账号类型设计到账号编码的生成，不允许修改
	*/
		@ApiModelProperty(value = "	账号类型	11：现金账户管理	12：记账账户管理	13：嘉联支付账户	14： 运直通支付账户	15: 兴业支付账户	账号类型设计到账号编码的生成，不允许修改")
		private Integer accountType;
	/**
	* 参数配置
	*/
		@ApiModelProperty(value = "参数配置")
		private String paramSettings;
	/**
	* 业务名称
	*/
		@ApiModelProperty(value = "业务名称")
		private String businessName;
	/**
	* 业务号
	*/
		@ApiModelProperty(value = "业务号")
		private String businessCode;
	/**
	* 支付渠道id
	*/
		@ApiModelProperty(value = "支付渠道id")
		private Long paymentChannelId;
	/**
	* 支付渠道机构号
	*/
		@ApiModelProperty(value = "支付渠道机构号")
		@TableField("channel_Institution_num")
	private String channelInstitutionNum;
	/**
	* 公钥
	*/
		@ApiModelProperty(value = "公钥")
		private String publicKey;
	/**
	* 私钥
	*/
		@ApiModelProperty(value = "私钥")
		private String privateKey;
	/**
	* md5加密字段
	*/
		@ApiModelProperty(value = "md5加密字段")
		private String md5;
	/**
	* 创建人
	*/
		@ApiModelProperty(value = "创建人")
		private Long createUser;
	/**
	* 创建部门
	*/
		@ApiModelProperty(value = "创建部门")
		private Long createDept;
	/**
	* 创建时间
	*/
		@ApiModelProperty(value = "创建时间")
		private LocalDateTime createTime;
	/**
	* 修改人
	*/
		@ApiModelProperty(value = "修改人")
		private Long updateUser;
	/**
	* 修改时间
	*/
		@ApiModelProperty(value = "修改时间")
		private LocalDateTime updateTime;
	/**
	* 状态
	*/
		@ApiModelProperty(value = "状态")
		private Integer status;
	/**
	* 是否启用0：启用，1：不启用
	*/
		@ApiModelProperty(value = "是否启用0：启用，1：不启用")
		private Integer isDeleted;

		private String creditNumber;
		private Integer creditName;
		private String accountName;
		private String mobile;
		private String idCard;
		private Integer payType;


}
